@@ -1,6 +1,6 @@
 #' Model summary for k-means clustering
 #'
-#' @param model Object of type \code{kmeans}.
+#' @param model Object of type `kmeans`.
 #' @inheritParams model_performance.lm
 #'
 #' @examples
@@ -16,10 +16,7 @@
 
 model_performance.kmeans <- function(model, verbose = TRUE, ...) {
   out <- as.data.frame(model[c("totss", "tot.withinss", "betweenss", "iter")])
-  colnames(out) <- c(
-    "Sum_Squares_Within", "Sum_Squares_Between", "Sum_Squares_Total",
-    "Iterations"
-  )
+  colnames(out) <- c("Sum_Squares_Total", "Sum_Squares_Within", "Sum_Squares_Between", "Iterations")
 
   row.names(out) <- NULL
   class(out) <- c("performance_model", class(out))
