@@ -1,36 +1,45 @@
 #' @title Bayesian R2
 #' @name r2_bayes
 #'
-#' @description Compute R2 for Bayesian models. For mixed models (including a
-#'   random part), it additionally computes the R2 related to the fixed effects
-#'   only (marginal R2). While `r2_bayes()` returns a single R2 value,
-#'   `r2_posterior()` returns a posterior sample of Bayesian R2 values.
+#' @description
+#' Compute R2 for Bayesian models. For mixed models (including a random part),
+#' it additionally computes the R2 related to the fixed effects only (marginal
+#' R2). While `r2_bayes()` returns a single R2 value, `r2_posterior()` returns a
+#' posterior sample of Bayesian R2 values.
 #'
 #' @param model A Bayesian regression model (from **brms**,
-#'   **rstanarm**, **BayesFactor**, etc).
+#' **rstanarm**, **BayesFactor**, etc).
 #' @param robust Logical, if `TRUE`, the median instead of mean is used to
-#'   calculate the central tendency of the variances.
+#' calculate the central tendency of the variances.
 #' @param ci Value or vector of probability of the CI (between 0 and 1) to be
-#'   estimated.
+#' estimated.
 #' @param ... Arguments passed to `r2_posterior()`.
 #' @inheritParams model_performance.lm
 #'
 #' @return A list with the Bayesian R2 value. For mixed models, a list with the
-#'   Bayesian R2 value and the marginal Bayesian R2 value. The standard errors
-#'   and credible intervals for the R2 values are saved as attributes.
+#' Bayesian R2 value and the marginal Bayesian R2 value. The standard errors and
+#' credible intervals for the R2 values are saved as attributes.
 #'
-#' @details `r2_bayes()` returns an "unadjusted" R2 value. See
-#'   [r2_loo()] to calculate a LOO-adjusted R2, which comes
-#'   conceptually closer to an adjusted R2 measure.
+#' @details
+#' `r2_bayes()` returns an "unadjusted" R2 value. See [`r2_loo()`] to calculate a
+#' LOO-adjusted R2, which comes conceptually closer to an adjusted R2 measure.
 #'
-#'   For mixed models, the conditional and marginal R2 are returned. The marginal
-#'   R2 considers only the variance of the fixed effects, while the conditional
-#'   R2 takes both the fixed and random effects into account.
+#' For mixed models, the conditional and marginal R2 are returned. The marginal
+#' R2 considers only the variance of the fixed effects, while the conditional R2
+#' takes both the fixed and random effects into account. Technically, since
+#' `r2_bayes()` relies on [`rstantools::bayes_R2()`], the "marginal" R2 calls
+#' `bayes_R2(re.form = NA)`, while the "conditional" R2 calls
+#' `bayes_R2(re.form = NULL)`. The `re.form` argument is passed to
+#' [`rstantools::posterior_epred()`], which is internally called in `bayes_R2()`.
 #'
-#'   `r2_posterior()` is the actual workhorse for `r2_bayes()` and
-#'   returns a posterior sample of Bayesian R2 values.
+#' Note that for "marginal" and "conditional", we refer to the wording suggested
+#' by _Nakagawa et al. 2017_. Thus, we don't use the term "marginal" in the sense
+#' that the random effects are integrated out, but are "ignored".
 #'
-#' @examplesIf require("rstanarm") && require("rstantools") && require("brms")
+#' `r2_posterior()` is the actual workhorse for `r2_bayes()` and returns a
+#' posterior sample of Bayesian R2 values.
+#'
+#' @examplesIf require("rstanarm") && require("rstantools") && require("brms") && require("RcppEigen")
 #' library(performance)
 #' \donttest{
 #' model <- suppressWarnings(rstanarm::stan_glm(
@@ -71,9 +80,13 @@
 #' r2_bayes(model)
 #' }
 #' @references
-#' Gelman, A., Goodrich, B., Gabry, J., and Vehtari, A. (2018).
-#' R-squared for Bayesian regression models. The American Statistician, 1–6.
-#' \doi{10.1080/00031305.2018.1549100}
+#' - Gelman, A., Goodrich, B., Gabry, J., and Vehtari, A. (2018). R-squared for
+#'   Bayesian regression models. The American Statistician, 1–6.
+#'   \doi{10.1080/00031305.2018.1549100}
+#' - Nakagawa, S., Johnson, P. C. D., and Schielzeth, H. (2017). The
+#'   coefficient of determination R2 and intra-class correlation coefficient from
+#'   generalized linear mixed-effects models revisited and expanded. Journal of
+#'   The Royal Society Interface, 14(134), 20170213.
 #' @export
 r2_bayes <- function(model, robust = TRUE, ci = 0.95, verbose = TRUE, ...) {
   r2_bayesian <- r2_posterior(model, verbose = verbose, ...)
@@ -184,20 +197,38 @@ r2_posterior.brmsfit <- function(model, verbose = TRUE, ...) {
           names(br2) <- res
         }
       } else if (mi$is_mixed) {
-        br2 <- list(
-          R2_Bayes = as.vector(rstantools::bayes_R2(
+        if (inherits(model, "stanreg")) {
+          pred_cond <- rstanarm::posterior_epred(
             model,
             re.form = NULL,
             re_formula = NULL,
-            summary = FALSE
-          )),
-          R2_Bayes_marginal = as.vector(rstantools::bayes_R2(
+          )
+          pred_marginal <- rstanarm::posterior_epred(
             model,
             re.form = NA,
             re_formula = NA,
-            summary = FALSE
-          ))
-        )
+          )
+          y <- insight::get_response(model)
+          br2 <- list(
+            R2_Bayes = as.vector(rstantools::bayes_R2(pred_cond, y = y)),
+            R2_Bayes_marginal = as.vector(rstantools::bayes_R2(pred_marginal, y = y))
+          )
+        } else {
+          br2 <- list(
+            R2_Bayes = as.vector(rstantools::bayes_R2(
+              model,
+              re.form = NULL,
+              re_formula = NULL,
+              summary = FALSE
+            )),
+            R2_Bayes_marginal = as.vector(rstantools::bayes_R2(
+              model,
+              re.form = NA,
+              re_formula = NA,
+              summary = FALSE
+            ))
+          )
+        }
         names(br2$R2_Bayes) <- rep("Conditional R2", length(br2$R2_Bayes))
         names(br2$R2_Bayes_marginal) <- rep("Marginal R2", length(br2$R2_Bayes))
       } else {
